==> annaffy_1.22.0.zip: annaffy/doc/annaffy.R <==
###################################################
### chunk number 1: 
###################################################
#line 72 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpZudtyb/R.INSTALL4d20140b/annaffy/inst/doc/annaffy.Rnw"
library("annaffy")


###################################################
### chunk number 2: 
###################################################
#line 79 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpZudtyb/R.INSTALL4d20140b/annaffy/inst/doc/annaffy.Rnw"
data(aafExpr)
probeids <- featureNames(aafExpr)
symbols <- aafSymbol(probeids, "hgu95av2.db")
symbols[[54]]
symbols[55:57]


###################################################
### chunk number 3: 
###################################################
#line 94 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpZudtyb/R.INSTALL4d20140b/annaffy/inst/doc/annaffy.Rnw"
getText(symbols[54:57])


###################################################
### chunk number 4: 
###################################################
#line 100 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpZudtyb/R.INSTALL4d20140b/annaffy/inst/doc/annaffy.Rnw"
gos <- aafGO(probeids, "hgu95av2.db")
gos[[3]]


###################################################
### chunk number 5: 
###################################################
#line 111 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpZudtyb/R.INSTALL4d20140b/annaffy/inst/doc/annaffy.Rnw"
gos[[3]][[1]]@name


###################################################
### chunk number 6: 
###################################################
#line 143 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpZudtyb/R.INSTALL4d20140b/annaffy/inst/doc/annaffy.Rnw"
gbs <- aafGenBank(probeids, "hgu95av2.db")
getURL(gbs[[1]])


###################################################
### chunk number 7: 
###################################################
#line 157 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpZudtyb/R.INSTALL4d20140b/annaffy/inst/doc/annaffy.Rnw"
lls <- aafLocusLink(probeids, "hgu95av2.db") 
getURL(lls[[2]])


###################################################
### chunk number 8: 
###################################################
#line 168 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpZudtyb/R.INSTALL4d20140b/annaffy/inst/doc/annaffy.Rnw"
bands <- aafCytoband(probeids, "hgu95av2.db") 
getURL(bands[[2]])


###################################################
### chunk number 9: 
###################################################
#line 180 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpZudtyb/R.INSTALL4d20140b/annaffy/inst/doc/annaffy.Rnw"
pmids <- aafPubMed(probeids, "hgu95av2.db")
getURL(pmids[[2]])


###################################################
### chunk number 10: 
###################################################
#line 191 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpZudtyb/R.INSTALL4d20140b/annaffy/inst/doc/annaffy.Rnw"
getURL(gos[[1]])


###################################################
### chunk number 11: 
###################################################
#line 199 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpZudtyb/R.INSTALL4d20140b/annaffy/inst/doc/annaffy.Rnw"
getURL(gos[[1]][[4]])


###################################################
### chunk number 12: 
###################################################
#line 210 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpZudtyb/R.INSTALL4d20140b/annaffy/inst/doc/annaffy.Rnw"
paths <- aafPathway(probeids, "hgu95av2.db")
getURL(paths[[4]])


###################################################
### chunk number 13: 
###################################################
#line 256 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpZudtyb/R.INSTALL4d20140b/annaffy/inst/doc/annaffy.Rnw"
library(multtest)


###################################################
### chunk number 14: 
###################################################
#line 265 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpZudtyb/R.INSTALL4d20140b/annaffy/inst/doc/annaffy.Rnw"
class <- as.integer(pData(aafExpr)$covar1) - 1


###################################################
### chunk number 15: 
###################################################
#line 275 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpZudtyb/R.INSTALL4d20140b/annaffy/inst/doc/annaffy.Rnw"
teststat <- mt.teststat(exprs(aafExpr), class)
index <- order(abs(teststat), decreasing = TRUE)
probeids <- featureNames(aafExpr)[index]


###################################################
### chunk number 16: 
###################################################
#line 292 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpZudtyb/R.INSTALL4d20140b/annaffy/inst/doc/annaffy.Rnw"
aaf.handler()


###################################################
### chunk number 17: 
###################################################
#line 299 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpZudtyb/R.INSTALL4d20140b/annaffy/inst/doc/annaffy.Rnw"
anncols <- aaf.handler()[c(1:3,8:9,11:13)]


###################################################
### chunk number 18: 
###################################################
#line 324 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpZudtyb/R.INSTALL4d20140b/annaffy/inst/doc/annaffy.Rnw"
anntable <- aafTableAnn(probeids[1:50], "hgu95av2.db", anncols)


###################################################
### chunk number 19: 
###################################################
#line 332 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpZudtyb/R.INSTALL4d20140b/annaffy/inst/doc/annaffy.Rnw"
saveHTML(anntable, "example1.html", title = "Example Table without Data")


###################################################
### chunk number 20: 
###################################################
#line 347 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpZudtyb/R.INSTALL4d20140b/annaffy/inst/doc/annaffy.Rnw"
testtable <- aafTable("t-statistic" = teststat[index[1:50]], signed = TRUE)
table <- merge(anntable, testtable)


###################################################
### chunk number 21: 
###################################################
#line 367 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpZudtyb/R.INSTALL4d20140b/annaffy/inst/doc/annaffy.Rnw"
exprtable <- aafTableInt(aafExpr, probeids = probeids[1:50])
table <- merge(table, exprtable)
saveHTML(table, "example2.html", title = "Example Table with Data")


###################################################
### chunk number 22: 
###################################################
#line 380 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpZudtyb/R.INSTALL4d20140b/annaffy/inst/doc/annaffy.Rnw"
saveText(table, "example2.txt")


###################################################
### chunk number 23: 
###################################################
#line 407 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpZudtyb/R.INSTALL4d20140b/annaffy/inst/doc/annaffy.Rnw"
library(hgu95av2.db)
probeids <- ls(hgu95av2SYMBOL)
gos <- aafGO(probeids[1:2], "hgu95av2.db")
getText(gos)


###################################################
### chunk number 24: 
###################################################
#line 419 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpZudtyb/R.INSTALL4d20140b/annaffy/inst/doc/annaffy.Rnw"
kinases <- aafSearchText("hgu95av2.db", "Description", "kinase")
kinases[1:5]
print(length(kinases))


###################################################
### chunk number 25: 
###################################################
#line 430 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpZudtyb/R.INSTALL4d20140b/annaffy/inst/doc/annaffy.Rnw"
probes <- aafSearchText("hgu95av2.db", c("Description", "Pathway"),
                        c("ribosome", "polymerase"))
print(length(probes))


###################################################
### chunk number 26: 
###################################################
#line 446 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpZudtyb/R.INSTALL4d20140b/annaffy/inst/doc/annaffy.Rnw"
probes <- aafSearchText("hgu95av2.db", "Description",
                        c("DNA", "polymerase"), logic = "AND")
print(length(probes))


###################################################
### chunk number 27: 
###################################################
#line 457 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpZudtyb/R.INSTALL4d20140b/annaffy/inst/doc/annaffy.Rnw"
gbs <- c("AF035121", "AL021546", "AJ006123", "AL080082", "AI289489")
aafSearchText("hgu95av2.db", "GenBank", gbs)


###################################################
### chunk number 28: 
###################################################
#line 483 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpZudtyb/R.INSTALL4d20140b/annaffy/inst/doc/annaffy.Rnw"
aafSearchGO("hgu95av2.db", c("GO:0000002", "GO:0000008"))
aafSearchGO("hgu95av2.db", c("2", "8"))
aafSearchGO("hgu95av2.db", c(2, 8))

==> annaffy_1.24.0.zip: annaffy/doc/annaffy.R <==
###################################################
### chunk number 1: 
###################################################
#line 72 "annaffy.Rnw"
library("annaffy")


###################################################
### chunk number 2: 
###################################################
#line 79 "annaffy.Rnw"
data(aafExpr)
probeids <- featureNames(aafExpr)
symbols <- aafSymbol(probeids, "hgu95av2.db")
symbols[[54]]
symbols[55:57]


###################################################
### chunk number 3: 
###################################################
#line 94 "annaffy.Rnw"
getText(symbols[54:57])


###################################################
### chunk number 4: 
###################################################
#line 100 "annaffy.Rnw"
gos <- aafGO(probeids, "hgu95av2.db")
gos[[3]]


###################################################
### chunk number 5: 
###################################################
#line 111 "annaffy.Rnw"
gos[[3]][[1]]@name


###################################################
### chunk number 6: 
###################################################
#line 143 "annaffy.Rnw"
gbs <- aafGenBank(probeids, "hgu95av2.db")
getURL(gbs[[1]])


###################################################
### chunk number 7: 
###################################################
#line 157 "annaffy.Rnw"
lls <- aafLocusLink(probeids, "hgu95av2.db") 
getURL(lls[[2]])


###################################################
### chunk number 8: 
###################################################
#line 168 "annaffy.Rnw"
bands <- aafCytoband(probeids, "hgu95av2.db") 
getURL(bands[[2]])


###################################################
### chunk number 9: 
###################################################
#line 180 "annaffy.Rnw"
pmids <- aafPubMed(probeids, "hgu95av2.db")
getURL(pmids[[2]])


###################################################
### chunk number 10: 
###################################################
#line 191 "annaffy.Rnw"
getURL(gos[[1]])


###################################################
### chunk number 11: 
###################################################
#line 199 "annaffy.Rnw"
getURL(gos[[1]][[4]])


###################################################
### chunk number 12: 
###################################################
#line 210 "annaffy.Rnw"
paths <- aafPathway(probeids, "hgu95av2.db")
getURL(paths[[4]])


###################################################
### chunk number 13: 
###################################################
#line 256 "annaffy.Rnw"
library(multtest)


###################################################
### chunk number 14: 
###################################################
#line 265 "annaffy.Rnw"
class <- as.integer(pData(aafExpr)$covar1) - 1


###################################################
### chunk number 15: 
###################################################
#line 275 "annaffy.Rnw"
teststat <- mt.teststat(exprs(aafExpr), class)
index <- order(abs(teststat), decreasing = TRUE)
probeids <- featureNames(aafExpr)[index]


###################################################
### chunk number 16: 
###################################################
#line 292 "annaffy.Rnw"
aaf.handler()


###################################################
### chunk number 17: 
###################################################
#line 299 "annaffy.Rnw"
anncols <- aaf.handler()[c(1:3,8:9,11:13)]


###################################################
### chunk number 18: 
###################################################
#line 324 "annaffy.Rnw"
anntable <- aafTableAnn(probeids[1:50], "hgu95av2.db", anncols)


###################################################
### chunk number 19: 
###################################################
#line 332 "annaffy.Rnw"
saveHTML(anntable, "example1.html", title = "Example Table without Data")


###################################################
### chunk number 20: 
###################################################
#line 347 "annaffy.Rnw"
testtable <- aafTable("t-statistic" = teststat[index[1:50]], signed = TRUE)
table <- merge(anntable, testtable)


###################################################
### chunk number 21: 
###################################################
#line 367 "annaffy.Rnw"
exprtable <- aafTableInt(aafExpr, probeids = probeids[1:50])
table <- merge(table, exprtable)
saveHTML(table, "example2.html", title = "Example Table with Data")


###################################################
### chunk number 22: 
###################################################
#line 380 "annaffy.Rnw"
saveText(table, "example2.txt")


###################################################
### chunk number 23: 
###################################################
#line 407 "annaffy.Rnw"
library(hgu95av2.db)
probeids <- ls(hgu95av2SYMBOL)
gos <- aafGO(probeids[1:2], "hgu95av2.db")
getText(gos)


###################################################
### chunk number 24: 
###################################################
#line 419 "annaffy.Rnw"
kinases <- aafSearchText("hgu95av2.db", "Description", "kinase")
kinases[1:5]
print(length(kinases))


###################################################
### chunk number 25: 
###################################################
#line 430 "annaffy.Rnw"
probes <- aafSearchText("hgu95av2.db", c("Description", "Pathway"),
                        c("ribosome", "polymerase"))
print(length(probes))


###################################################
### chunk number 26: 
###################################################
#line 446 "annaffy.Rnw"
probes <- aafSearchText("hgu95av2.db", "Description",
                        c("DNA", "polymerase"), logic = "AND")
print(length(probes))


###################################################
### chunk number 27: 
###################################################
#line 457 "annaffy.Rnw"
gbs <- c("AF035121", "AL021546", "AJ006123", "AL080082", "AI289489")
aafSearchText("hgu95av2.db", "GenBank", gbs)


###################################################
### chunk number 28: 
###################################################
#line 483 "annaffy.Rnw"
aafSearchGO("hgu95av2.db", c("GO:0000002", "GO:0000008"))
aafSearchGO("hgu95av2.db", c("2", "8"))
aafSearchGO("hgu95av2.db", c(2, 8))
